Index: src/southbridge/intel/i82371eb/i82371eb_isa.c
===================================================================
--- src/southbridge/intel/i82371eb/i82371eb_isa.c	(revision 4869)
+++ src/southbridge/intel/i82371eb/i82371eb_isa.c	(working copy)
@@ -29,7 +29,6 @@
 
 static void isa_init(struct device *dev)
 {
-	u16 reg16;
 	u32 reg32;
 
 	/* Initialize the real time clock (RTC). */
Index: src/southbridge/intel/i82371eb/i82371eb.h
===================================================================
--- src/southbridge/intel/i82371eb/i82371eb.h	(revision 4869)
+++ src/southbridge/intel/i82371eb/i82371eb.h	(working copy)
@@ -24,6 +24,7 @@
 #ifndef __ROMCC__
 #include "chip.h"
 void i82371eb_enable(device_t dev);
+void i82371eb_hard_reset(void);
 #endif
 
 /* If 'cond' is true this macro sets the bit(s) specified by 'bits' in the
Index: src/devices/device_util.c
===================================================================
--- src/devices/device_util.c	(revision 4869)
+++ src/devices/device_util.c	(working copy)
@@ -556,7 +556,7 @@
 	}
 }
 
-void resource_tree(struct device *root, int debug_level, int depth)
+static void resource_tree(struct device *root, int debug_level, int depth)
 {
 	int i = 0, link = 0;
 	struct device *child;
Index: src/include/cpu/x86/tsc.h
===================================================================
--- src/include/cpu/x86/tsc.h	(revision 4869)
+++ src/include/cpu/x86/tsc.h	(working copy)
@@ -24,6 +24,8 @@
 	asm volatile ("rdtsc" : "=A" (val));
 	return val;
 }
+
+void init_timer(void);
 #endif
 
 
Index: src/include/cpu/x86/mtrr.h
===================================================================
--- src/include/cpu/x86/mtrr.h	(revision 4869)
+++ src/include/cpu/x86/mtrr.h	(working copy)
@@ -34,10 +34,14 @@
 
 #if !defined(__ROMCC__) && !defined (ASSEMBLY)
 
+#include <device/device.h>
 
+void enable_fixed_mtrr(void);
 void x86_setup_var_mtrrs(unsigned address_bits);
 void x86_setup_mtrrs(unsigned address_bits);
 int x86_mtrr_check(void);
+void set_var_mtrr_resource(void *gp, struct device *dev, struct resource *res);
+void x86_setup_fixed_mtrrs(void);
 
 #endif /* __ROMCC__ */
 
Index: src/include/device/device.h
===================================================================
--- src/include/device/device.h	(revision 4869)
+++ src/include/device/device.h	(working copy)
@@ -132,6 +132,7 @@
 void show_devs_tree(struct device *dev, int debug_level, int depth, int linknum);
 void show_devs_subtree(struct device *root, int debug_level, const char *msg);
 void show_all_devs(int debug_level, const char *msg);
+void show_all_devs_tree(int debug_level, const char *msg);
 void show_one_resource(int debug_level, struct device *dev,
 		       struct resource *resource, const char *comment);
 void show_all_devs_resources(int debug_level, const char* msg);
@@ -152,4 +153,5 @@
 void root_dev_enable_resources(device_t dev);
 unsigned int root_dev_scan_bus(device_t root, unsigned int max);
 void root_dev_init(device_t dev);
+void root_dev_reset(struct bus *bus);
 #endif /* DEVICE_H */
Index: src/include/cbmem.h
===================================================================
--- src/include/cbmem.h	(revision 4869)
+++ src/include/cbmem.h	(working copy)
@@ -45,5 +45,7 @@
 int cbmem_reinit(u64 baseaddr);
 void *cbmem_add(u32 id, u64 size);
 void *cbmem_find(u32 id);
+void cbmem_list(void);
+void cbmem_arch_init(void);
 
 #endif
Index: src/lib/cbmem.c
===================================================================
--- src/lib/cbmem.c	(revision 4869)
+++ src/lib/cbmem.c	(working copy)
@@ -90,7 +90,7 @@
 	struct cbmem_entry *cbmem_toc;
 	cbmem_toc = (struct cbmem_entry *)(unsigned long)baseaddr;
 
-	debug("Re-Initializing CBMEM area to 0x%lx\n", baseaddr);
+	debug("Re-Initializing CBMEM area to 0x%lx\n", (unsigned long)baseaddr);
 #ifndef __ROMCC__
 	bss_cbmem_toc = cbmem_toc;
 #endif
@@ -212,7 +212,7 @@
 #endif
 	
 	if (cbmem_toc == NULL)
-		return NULL;
+		return;
 
 	for (i = 0; i < MAX_CBMEM_ENTRIES; i++) {
 
Index: src/pc80/mc146818rtc.c
===================================================================
--- src/pc80/mc146818rtc.c	(revision 4869)
+++ src/pc80/mc146818rtc.c	(working copy)
@@ -133,8 +133,10 @@
 
 void rtc_init(int invalid)
 {
+#if CONFIG_HAVE_OPTION_TABLE
 	unsigned char x;
 	int cmos_invalid, checksum_invalid;
+#endif
 
 	printk_debug("RTC Init\n");
 
Index: src/pc80/udelay_io.c
===================================================================
--- src/pc80/udelay_io.c	(revision 4869)
+++ src/pc80/udelay_io.c	(working copy)
@@ -1,4 +1,5 @@
 #include <arch/io.h>
+#include <delay.h>
 
 void udelay(unsigned usecs)
 {
Index: src/arch/i386/boot/tables.c
===================================================================
--- src/arch/i386/boot/tables.c	(revision 4869)
+++ src/arch/i386/boot/tables.c	(working copy)
@@ -34,8 +34,6 @@
 uint64_t high_tables_base = 0;
 uint64_t high_tables_size;
 
-void cbmem_list(void);
-
 void move_gdt(void);
 void cbmem_arch_init(void)
 {
Index: util/x86emu/x86.c
===================================================================
--- util/x86emu/x86.c	(revision 4869)
+++ util/x86emu/x86.c	(working copy)
@@ -124,8 +125,6 @@
 
 void run_bios(struct device *dev, unsigned long addr)
 {
-	int i;
-
 	/* clear vga bios data area */
 	memset(0x400, 0, 0x200);
 	
